# Harness-Bench Comparison Report

**Date:** 2026-02-22T14:14:25
**Tasks:** 8

## Overall Results

| Agent |
|-------|

## Per-Task Results

## Timing

| Agent | Model | Avg Duration | Total Duration |
|-------|-------|-------------|----------------|
